summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteprotocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteprotocol.h')
-rw-r--r--kopete/libkopete/kopeteprotocol.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kopeteprotocol.h b/kopete/libkopete/kopeteprotocol.h
index 1b1d7c08..f27c90f5 100644
--- a/kopete/libkopete/kopeteprotocol.h
+++ b/kopete/libkopete/kopeteprotocol.h
@@ -160,11 +160,11 @@ protected:
/**
* @brief Constructor for Protocol
*
* @param instance The protocol's instance, every plugin needs to have a KInstance of its own
* @param parent The protocol's parent object
* @param name The protocol's name
*/
- Protocol( KInstance *instance, TQObject *parent, const char *name );
+ Protocol( TDEInstance *instance, TQObject *parent, const char *name );
/**
* @brief Sets the capabilities of this protcol.
@@ -160,11 +160,11 @@ protected:
* @brief Constructor for Protocol
*
- * @param instance The protocol's instance, every plugin needs to have a KInstance of its own
+ * @param instance The protocol's instance, every plugin needs to have a TDEInstance of its own
* @param parent The protocol's parent object
* @param name The protocol's name